@@ -52,7 +52,7 @@ rollapply.zoo <- function(data, width, FUN, ..., by = 1,
 	}
 
     if (is.vector(width) && !is.list(width) && length(width) == 1 &&
-		by.column && length(by) == 1 && by == 1 && 
+		by.column && length(by) == 1 && by == 1 && (missing(partial) | identical(partial, FALSE)) &&
 		length(list(...)) < 1 && length(sw <- deparse(substitute(FUN))) == 1) {
 		  if (sw == "mean" && all(!is.na(data))) {
 				return(rollmean(data, width, fill = fill, align = align))
@@ -83,16 +83,16 @@ rollapply.zoo <- function(data, width, FUN, ..., by = 1,
 	align <- match.arg(align)
 
 	if (!is.list(width)) width <- lapply(width, function(w) {
-			if (align == "right") seq(to = 0, length = w)
-			else if (align == "center") seq(to = floor(w/2), length = w)
-			else seq(from = 0, length = w)
+			if (align == "right") seq(to = 0, length.out = w)
+			else if (align == "center") seq(to = floor(w/2), length.out = w)
+			else seq(from = 0, length.out = w)
 	})
 	# recycle width (using by if length(width) == 1)
 	width <- if (length(width) == 1) {
 		w <- rep(list(NULL), NROW(data))
 		start.at <- if (partial < 0) max(-min(width[[1]]), 0) + 1 else 1
 		replace(w, seq(start.at, NROW(data), by = by), width)
-	} else rep(width, length = NROW(data))
+	} else rep(width, length.out = NROW(data))
 
 	f <- if (is.null(dim(data))) {
 		# undimensioned
@@ -104,9 +104,9 @@ rollapply.zoo <- function(data, width, FUN, ..., by = 1,
 			posns <- i + offsets
 			ix <- posns >= 1 & posns <= NROW(data)
 			if (partial < 0) {
-				if (all(ix)) FUN(coredata(data)[posns], ...)
+				if (all(ix)) FUN(data[posns], ...)
 			} else if (sum(ix) >= partial) {
-				FUN(coredata(data)[replace(posns, !ix, 0)], ...)
+				FUN(data[replace(posns, !ix, 0)], ...)
 			}
 		}
     } else {
@@ -118,15 +118,15 @@ rollapply.zoo <- function(data, width, FUN, ..., by = 1,
 			posns <- i + offsets
 			ix <- posns >= 1 & posns <= NROW(data)
 			if (partial < 0) {
-				if (all(ix)) FUN(coredata(data)[posns,], ...)
+				if (all(ix)) FUN(data[posns,], ...)
 			} else if (sum(ix) >= partial) {
-				FUN(coredata(data)[replace(posns, !ix, 0),], ...)
+				FUN(data[replace(posns, !ix, 0),], ...)
 			}
 		}
 	}
 
 	dat <- mapply(f, seq_along(time(data)), width, 
-		MoreArgs = list(data = data, ...), SIMPLIFY = FALSE) 
+		MoreArgs = list(data = coredata(data), ...), SIMPLIFY = FALSE) 
 		
 	ix <- !sapply(dat, is.null) # integer indexes of non-nulls
 
